@@ -87,7 +87,7 @@ def load_image(img):
 
 	return img
 
-def detect_face(img, detector_backend = 'retinaface', grayscale = False, enforce_detection = True, align = True):
+def detect_face(img, detector_backend = 'opencv', grayscale = False, enforce_detection = True, align = True):
 
 	img_region = [0, 0, img.shape[0], img.shape[1]]
 
@@ -106,7 +106,7 @@ def detect_face(img, detector_backend = 'retinaface', grayscale = False, enforce
 			else:
 			  raise ValueError("Face could not be detected. Please confirm that the picture is a face photo or consider to set enforce_detection param to False.")
 
-def preprocess_face(img, target_size=(224, 224), grayscale = False, enforce_detection = True, detector_backend = 'retinaface', return_region = False, align = True):
+def preprocess_face(img, target_size=(224, 224), grayscale = False, enforce_detection = True, detector_backend = 'opencv', return_region = False, align = True):
 
 	#img might be path, base64 or numpy array. Convert it to numpy whatever it is.
 	img = load_image(img)
